@@ -7,7 +7,7 @@
 ################################################################################
 package Apache::Voodoo::Debug::Common;
 
-$VERSION = "3.0100";
+$VERSION = "3.0200";
 
 use strict;
 use warnings;
@@ -55,10 +55,10 @@ sub stack_trace {
 	my $i = 1;
 
 	my $st = Devel::StackTrace->new();
-    while (my $frame = $st->frame($i++)) {
+	while (my $frame = $st->frame($i++)) {
 		last if ($frame->package =~ /^Apache::Voodoo::Engine/);
-        next if ($frame->package =~ /^Apache::Voodoo/);
-        next if ($frame->package =~ /(eval)/);
+		next if ($frame->package =~ /^Apache::Voodoo/);
+		next if ($frame->package =~ /(eval)/);
 
 		my $f = {
 			'class'    => $frame->package,
@@ -78,24 +78,24 @@ sub stack_trace {
 		else {
 			$f->{'type'} = '::';
 		}
-		$f->{instruction} = $f->{class}.$f->{type}.$f->{function};
+		$f->{'instruction'} = $f->{'class'}.$f->{'type'}.$f->{'function'};
 
 		push(@trace,$f);
 
 		if ($full) {
 			$f->{'args'} = \@a;
 		}
-    }
+	}
 	return @trace;
 }
 
 1;
 
 ################################################################################
-# Copyright (c) 2005-2010 Steven Edwards (maverick@smurfbane.org).  
+# Copyright (c) 2005-2010 Steven Edwards (maverick@smurfbane.org).
 # All rights reserved.
 #
-# You may use and distribute Apache::Voodoo under the terms described in the 
+# You may use and distribute Apache::Voodoo under the terms described in the
 # LICENSE file include in this package. The summary is it's a legalese version
 # of the Artistic License :)
 #
