@@ -27,6 +27,111 @@
 
 */
 
+function voodooJson() {
+	//////////////////////////////////////////////////////////////////////////////////
+	// JSON library
+	//
+	// The stringify function and it's supporting functions have been removed
+	// since this object only needs the parse function.
+	// The comments were extremely verbose and have been removed.
+	//////////////////////////////////////////////////////////////////////////////////
+	this.f = function (n) {
+		return n<10?'0'+n:n;
+	};
+
+	if (typeof Date.prototype.toJSON !== 'function') {
+		Date.prototype.toJSON = function(key) {
+			return this.getUTCFullYear()+'-'+f(this.getUTCMonth()+1)+'-'+f(this.getUTCDate())+'T'+f(this.getUTCHours())+':'+f(this.getUTCMinutes())+':'+f(this.getUTCSeconds())+'Z';
+		};
+		String.prototype.toJSON = Number.prototype.toJSON = Boolean.prototype.toJSON = function (key) {
+			return this.valueOf();
+		};
+	}
+	var cx=/[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,escapeable=/[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,gap,indent,meta={'\b':'\\b','\t':'\\t','\n':'\\n','\f':'\\f','\r':'\\r','"':'\\"','\\':'\\\\'},rep;
+
+	this.parse = function(text,reviver) {
+		var j;
+		function walk(holder,key) {
+			var k,v,value = holder[key];
+			if (value&&typeof value==='object') {
+				for (k in value) {
+					if (Object.hasOwnProperty.call(value,k)) {
+						v = walk(value,k);
+						if (v!==undefined) {
+							value[k]=v;
+						}
+						else {
+							delete value[k];
+						}
+					}
+				}
+			}
+			return reviver.call(holder,key,value);
+		}
+		cx.lastIndex=0;
+		if (cx.test(text)) {
+			text=text.replace(cx,
+				function(a) {
+					return '\\u'+('0000'+a.charCodeAt(0).toString(16)).slice(-4);
+				}
+			);
+		}
+		if (/^[\],:{}\s]*$/.test(text.replace(/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,'@').replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,']').replace(/(?:^|:|,)(?:\s*\[)+/g,''))) {
+			j = eval('('+text+')');
+			return typeof reviver==='function'?walk({'':j},''):j;
+		}
+		throw new SyntaxError('voodooDebug.parse');
+	};
+}
+
+function voodooAjax() {
+	//////////////////////////////////////////////////////////////////////////////////
+	// Feather Ajax
+	//////////////////////////////////////////////////////////////////////////////////
+
+	// reference to the calling object
+	this.caller = null;
+
+	// ..and the associated set method
+	this.setResponseHandler = function(obj) {
+		this.caller = obj;
+	};
+
+	this.createRequestObject = function() {
+		var ro;
+		try {
+			ro=new XMLHttpRequest();
+		}
+		catch(e) {
+			ro=new ActiveXObject("Microsoft.XMLHTTP");
+		}
+		return ro;
+	};
+
+	this.http = this.createRequestObject();
+	var me = this;
+	this.sndReq = function(action,url,data) {
+		if (action.toUpperCase()=="POST") {
+			this.http.open(action,url,true);
+			this.http.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
+			this.http.onreadystatechange=this.handleResponse;
+			this.http.send(data);
+		}
+		else {
+			this.http.open(action,url+'?'+data,true);
+			this.http.onreadystatechange=this.handleResponse;
+			this.http.send(null);
+		}
+	};
+
+	this.handleResponse = function() {
+		// Stripped down to only call the response handler passing it the response content
+		if (me.http.readyState==4) {
+			me.caller.handleResponse(me.http.responseText);
+		}
+	};
+}
+
 function voodooDebug(opts) {
 	this.debug_root = opts.debug_root;
 	this.app_id     = opts.app_id;
@@ -66,14 +171,14 @@ function voodooDebug(opts) {
 
 	this.parser = new voodooJson();
 
-	this.imgLevels = new Object();
+	this.imgLevels = {};
 	for (var key in this.levels) {
 		this.imgLevels[key] = new Image(12,12);
 		this.imgLevels[key].src = this.debug_root+"/"+key+".png";
 	}
 
 	this.yourBrowserIsBroken = (navigator.userAgent.toLowerCase().indexOf("msie")!=-1);
-	
+
 	////////////////////////////////////////////////////////////////////////////////
 	//
 	// PUBLIC METHODS
@@ -87,21 +192,21 @@ function voodooDebug(opts) {
 		             '&request_id='+this.origin_id;
 
 		this.sendRequest('request',params);
-	}
+	};
 
 	// Changes the which request we're looking at; refreshes all the open sections
 	this.changeRequest = function(obj) {
 		this.request_id = obj.value;
-		for (section in this.openSections) {
+		for (var section in this.openSections) {
 			if (this.openSections[section]) {
 				this.loadSection(section);
 			}
 		}
-	}
-	
+	};
+
 	// Changes the debug block filtering options
 	this.filterDebug = function(obj,level) {
-		document.getElementById("vd_debug").innerHTML = '<img src="'+this.imgSpinner.src+'">';	
+		document.getElementById("vd_debug").innerHTML = '<img src="'+this.imgSpinner.src+'">';
 		this.levels[level] = (this.levels[level])?0:1;
 
 		var params = 'app_id='     +this.app_id+
@@ -112,7 +217,7 @@ function voodooDebug(opts) {
 			params += '&' + i + '='	+ this.levels[i];
 		}
 		this.sendRequest('debug',params);
-	}
+	};
 
 	// Handles the opening or closing of the various debug panels
 	this.handleSection = function(obj, section) {
@@ -155,9 +260,9 @@ function voodooDebug(opts) {
 			}
 		}
 		return false;
-	}
+	};
+
 
-	
 	////////////////////////////////////////////////////////////////////////////////
 	//
 	// Methods associated with making the ajax requests
@@ -167,7 +272,7 @@ function voodooDebug(opts) {
 	// Replaces the newly opened (or refreshed) sub panel's contents with the spinner
 	// image and fires the ajax request pull down the content
 	this.loadSection = function(section) {
-		document.getElementById("vd_"+section).innerHTML = '<img src="'+this.imgSpinner.src+'">';	
+		document.getElementById("vd_"+section).innerHTML = '<img src="'+this.imgSpinner.src+'">';
 
 		var params = 'app_id='     +this.app_id+
 		             '&session_id='+this.session_id+
@@ -179,13 +284,13 @@ function voodooDebug(opts) {
 			}
 		}
 		this.sendRequest(section,params);
-	}
+	};
 
 	this.sendRequest = function(addr,params) {
 		var ajax = new voodooAjax();
 		ajax.setResponseHandler(this);
 		ajax.sndReq('get',this.debug_root+"/"+addr,params);
-	}
+	};
 
 
 	////////////////////////////////////////////////////////////////////////////////
@@ -193,13 +298,13 @@ function voodooDebug(opts) {
 	// Methods for handling the ajax response and creating the display
 	//
 	////////////////////////////////////////////////////////////////////////////////
-	
+
 	// Main ajax response handler, all ajax responses enter here.
 	this.handleResponse = function(rawdata) {
 		var data = this.parser.parse(rawdata);
 
 		var h;
-		if (data.value == null || data.value.length <= 0 ) {
+		if (data.value === null || data.value.length <= 0 ) {
 			h = "<i>(empty)</i>";
 		}
 		else {
@@ -219,7 +324,7 @@ function voodooDebug(opts) {
 			}
 		}
 		document.getElementById(data.key).innerHTML = h;
-	}
+	};
 
 	// Updates the select list of requests.
 	this.handleListRequests = function(data) {
@@ -234,7 +339,7 @@ function voodooDebug(opts) {
 				select.selectedIndex = i;
 			}
 		}
-	}
+	};
 
 	this.handleTable = function(data) {
 		var h = '<table>';
@@ -249,44 +354,46 @@ function voodooDebug(opts) {
 		}
 		h += "</table>";
 		return h;
-	}
+	};
 
 	this.handleDebug = function(data) {
-		var stack = new Array();
+		var i;
+
+		var stack = [];
 
 		var h = '<ul>';
-		for (var i=0; i < data.length; i++) {
+		for (i=0; i < data.length; i++) {
 			var row = data[i];
 			var rstack = row.stack.reverse();
 
 			if (rstack.length > 0) {
 				var depth;
 				for (depth=0; depth < rstack.length || depth < stack.length; depth++) {
-					if (rstack[depth]         == undefined ||
-						stack[depth]          == undefined ||
-						stack[depth].class    != rstack[depth].class ||
-						stack[depth].function != rstack[depth].function) {
+					if (rstack[depth]                === undefined ||
+						stack[depth]             === undefined ||
+						stack[depth]['class']    !== rstack[depth]['class'] ||
+						stack[depth]['function'] !== rstack[depth]['function']) {
 
 						while (stack.length > depth) {
 							// pop stack up to the point that everything matches
 							h += '</li></ul>';
 							stack.pop();
 						}
-						
-						if (rstack[depth] != undefined) {
+
+						if (rstack[depth] !== undefined) {
 							// push new item
 							stack.push(rstack[depth]);
 							h += '<li class="vdOpen"><span class="vdClick" onClick="vdDebug.toggleUL(this);">'+
 								'<img src="'+this.imgMinus.src+'" />'+
-								rstack[depth].class + 
-								rstack[depth].type.replace('<','&lt;').replace('>','&gt;') + 
-								rstack[depth].function + "</span><ul>";
+								rstack[depth]['class'] +
+								rstack[depth]['type'].replace('<','&lt;').replace('>','&gt;') +
+								rstack[depth]['function'] + "</span><ul>";
 						}
 					}
 				}
-				h += '<li><img src="'+this.imgLevels[row.level].src+'"/> ' + rstack[0].line + ':';
+				h += '<li><img src="'+this.imgLevels[row.level].src+'"/> ' + rstack[0]['line'] + ':';
 			}
-				
+
 			if (row.level == "table") {
 				h += row.data[0];
 				h += this.handleTable(data[i].data[1]);
@@ -303,31 +410,33 @@ function voodooDebug(opts) {
 		}
 
 		// close all the openg dl's.  This will be however deep the stack is.
-		for (var i=0; i <= stack.length; i++) {
+		for (i=0; i <= stack.length; i++) {
 			h += '</li></ul>';
 		}
 
 		return h;
-	}
+	};
 
 	this.convertStackToTable = function(data) {
-		var t = new Array();
-		t.push(new Array('Class','Subroutine','Line','Args'));
+		var t = [];
+		t.push(['Class','Subroutine','Line','Args']);
 		for (var i=0; i<data.length; i++) {
-			var args = new Array();
-			for (var j=0; j<data[i].args.length; j++) {
-				args.push(this.dumpData(data[i].args[j],true));
+			var args = [];
+			if (data[i]['args'] instanceof Array) {
+				for (var j=0; j<data[i]['args'].length; j++) {
+					args.push(this.dumpData(data[i]['args'][j],true));
+				}
 			}
 
-			t.push(new Array(
-				data[i].class,
-				data[i].function,
-				data[i].line,
+			t.push([
+				data[i]['class'],
+				data[i]['function'],
+				data[i]['line'],
 				args.join(',')
-			));
+			]);
 		}
 		return t;
-	}
+	};
 
 	this.handleReturnData = function(data) {
 		var h = '<dl>';
@@ -337,15 +446,15 @@ function voodooDebug(opts) {
 		h += '</dl>';
 		return h;
 
-	}
+	};
 
 	// walks a JSON data structure and creates a collapsible view of it.
 	this.dumpData = function(data,closed) {
-		if (data == null) {
+		var a = [];
+		if (data === null) {
 			return "<i>undefined</i>";
 		}
 		else if (data.constructor == Object) {
-			var a = new Array();
 			for (var key in data) {
 				a.push('<li>' + key + ' => ' + this.dumpData(data[key]));
 			}
@@ -359,7 +468,6 @@ function voodooDebug(opts) {
 		}
 		else if (data.constructor == Array) {
 			if (data.length > 0) {
-				var a = new Array();
 				for (var j=0; j < data.length; j++) {
 					a.push('<li>' + this.dumpData(data[j]));
 				}
@@ -370,10 +478,10 @@ function voodooDebug(opts) {
 			}
 		}
 		else {
-			var d = new String(data);
+			var d = String(data);
 			return '"' + d.replace(/"/g,'\\"').replace('<','&lt;').replace('>','&gt;') + '"';
 		}
-	}
+	};
 
 	this._mkblock = function(a,closed,l,r) {
 		var o = 'vdVisible';
@@ -386,7 +494,7 @@ function voodooDebug(opts) {
 		var id = this.makeId();
 		return '<span class="'+c+'" id="' +id+'-c"><span class="vdClick" onClick="vdDebug.toggleData(\''+id+'\')">'+l+'<i>' + a.length + ' elements...</i>'+r+'</span></span>'+
 		       '<span class="'+o+'" id="' +id+'-o"><span class="vdClick" onClick="vdDebug.toggleData(\''+id+'\')">'+l+'</span><ul>' + a.join(",</li>") + '</li></ul>'+r+'</span';
-	}
+	};
 
 	this.toggleUL = function(obj) {
 		if (obj.parentNode.className == "vdOpen") {
@@ -397,7 +505,7 @@ function voodooDebug(opts) {
 			obj.parentNode.className = "vdOpen";
 			obj.firstChild.src=this.imgMinus.src;
 		}
-	}
+	};
 
 	this.toggleData = function(id) {
 		var first  = document.getElementById(id+'-c');
@@ -405,114 +513,10 @@ function voodooDebug(opts) {
 		var tmp = first.className;
 		first.className = second.className;
 		second.className = tmp;
-	}
+	};
 
 	this.makeId = function() {
 		this.elementid += 1;
 		return 'voodooDebug_id_'+this.elementid;
-	}
-}
-
-function voodooJson() {
-	//////////////////////////////////////////////////////////////////////////////////
-	// JSON library
-	//
-	// The stringify function and it's supporting functions have been removed
-	// since this object only needs the parse function.
-	// The comments were extremely verbose and have been removed.
-	//////////////////////////////////////////////////////////////////////////////////
-	this.f = function (n) {
-		return n<10?'0'+n:n;
-	}
-
-	if (typeof Date.prototype.toJSON !== 'function') {
-		Date.prototype.toJSON = function(key) {
-			return this.getUTCFullYear()+'-'+f(this.getUTCMonth()+1)+'-'+f(this.getUTCDate())+'T'+f(this.getUTCHours())+':'+f(this.getUTCMinutes())+':'+f(this.getUTCSeconds())+'Z';
-		}
-		String.prototype.toJSON = Number.prototype.toJSON = Boolean.prototype.toJSON = function (key) {
-			return this.valueOf();
-		}
-	}
-	var cx=/[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,escapeable=/[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,gap,indent,meta={'\b':'\\b','\t':'\\t','\n':'\\n','\f':'\\f','\r':'\\r','"':'\\"','\\':'\\\\'},rep;
-
-	this.parse = function(text,reviver) {
-		var j;
-		function walk(holder,key) {
-			var k,v,value = holder[key];
-			if (value&&typeof value==='object') {
-				for (k in value) {
-					if (Object.hasOwnProperty.call(value,k)) {
-						v = walk(value,k);
-						if (v!==undefined) {
-							value[k]=v;
-						}
-						else {
-							delete value[k];
-						}
-					}
-				}
-			}
-			return reviver.call(holder,key,value);
-		}
-		cx.lastIndex=0;
-		if (cx.test(text)) {
-			text=text.replace(cx,
-				function(a) {
-					return '\\u'+('0000'+a.charCodeAt(0).toString(16)).slice(-4);
-				}
-			);
-		}
-		if (/^[\],:{}\s]*$/.test(text.replace(/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,'@').replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,']').replace(/(?:^|:|,)(?:\s*\[)+/g,''))) {
-			j = eval('('+text+')');
-			return typeof reviver==='function'?walk({'':j},''):j;
-		}
-		throw new SyntaxError('voodooDebug.parse');
-	}
-}
-
-function voodooAjax() {
-	//////////////////////////////////////////////////////////////////////////////////
-	// Feather Ajax
-	//////////////////////////////////////////////////////////////////////////////////
-
-	// reference to the calling object
-	this.caller = null;
-
-	// ..and the associated set method
-	this.setResponseHandler = function(obj) {
-		this.caller = obj;
-	}
-
-	this.createRequestObject = function() {
-		try {
-			var ro=new XMLHttpRequest();
-		}
-		catch(e) {
-			var ro=new ActiveXObject("Microsoft.XMLHTTP");
-		}
-		return ro;
-	}
-
-	this.http = this.createRequestObject();
-	var me = this;
-	this.sndReq = function(action,url,data) {
-		if (action.toUpperCase()=="POST") {
-			this.http.open(action,url,true);
-			this.http.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-			this.http.onreadystatechange=this.handleResponse;
-			this.http.send(data);
-		}
-		else {
-			this.http.open(action,url+'?'+data,true);
-			this.http.onreadystatechange=this.handleResponse;
-			this.http.send(null);
-		}
-	}
-
-	this.handleResponse = function() {
-		// Stripped down to only call the response handler passing it the response content
-		if (me.http.readyState==4) {
-			me.caller.handleResponse(me.http.responseText);
-		}
-	}
+	};
 }
